@@ -14,10 +14,12 @@ test_that("Grids online", {
   expect_s3_class(g100, "sf")
   expect_message(g100 <- suppressWarnings(gisco_get_grid(100, verbose = TRUE)))
   expect_s3_class(g100, "sf")
-  expect_message(suppressWarnings(gisco_get_grid(100,
-    spatialtype = "POINT",
-    verbose = TRUE
-  )))
+  expect_message(suppressWarnings(
+    gisco_get_grid(100,
+      spatialtype = "POINT",
+      verbose = TRUE
+    )
+  ))
 })
 
 test_that("Offline", {
